#!/usr/bin/env python
###########################################################################
#
# Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
#
# PyQt port in September 2010 by Hans-Peter Jansen <hpj@urpla.net>
#
###########################################################################

# This is only needed for Python v2 but is harmless for Python v3.
import sip
sip.setapi('QString', 2)

from PyQt4 import QtCore, QtGui, QtSvg

import delayedencoding_rc


class MimeData(QtCore.QMimeData):

    dataRequested = QtCore.pyqtSignal(str)

    def formats(self):
        formats = QtCore.QMimeData.formats(self)
        formats.append('image/png')

        return formats

    def retrieveData(self, mimeType, qvtype):
        self.dataRequested.emit(mimeType)

        return QtCore.QMimeData.retrieveData(self, mimeType, qvtype)


class SourceWidget(QtGui.QWidget):
    def __init__(self, parent=None):
        super(SourceWidget, self).__init__(parent)

        self.mimeData = None

        imageFile = QtCore.QFile(':/images/example.svg')
        imageFile.open(QtCore.QIODevice.ReadOnly)
        self.imageData = imageFile.readAll()
        imageFile.close()

        imageArea = QtGui.QScrollArea()
        self.imageLabel = QtSvg.QSvgWidget()
        self.imageLabel.renderer().load(self.imageData)
        imageArea.setWidget(self.imageLabel)

        instructTopLabel = QtGui.QLabel("This is an SVG drawing:")
        instructBottomLabel = QtGui.QLabel("Drag the icon to copy the drawing as a PNG file:")
        dragIcon = QtGui.QPushButton("Export")
        dragIcon.setIcon(QtGui.QIcon(':/images/drag.png'))
        dragIcon.pressed.connect(self.startDrag)

        layout = QtGui.QGridLayout()
        layout.addWidget(instructTopLabel, 0, 0, 1, 2)
        layout.addWidget(imageArea, 1, 0, 2, 2)
        layout.addWidget(instructBottomLabel, 3, 0)
        layout.addWidget(dragIcon, 3, 1)
        self.setLayout(layout)
        self.setWindowTitle("Delayed Encoding")

    def createData(self, mimeType):
        if mimeType != 'image/png':
            return

        image = QtGui.QImage(self.imageLabel.size(), QtGui.QImage.Format_RGB32)
        painter = QtGui.QPainter()
        painter.begin(image)
        self.imageLabel.renderer().render(painter)
        painter.end()

        data = QtCore.QByteArray()
        buffer = QtCore.QBuffer(data)
        buffer.open(QtCore.QIODevice.WriteOnly)
        image.save(buffer, 'PNG')
        buffer.close()
        self.mimeData.setData('image/png', data)

    def startDrag(self):
        self.mimeData = MimeData()
        self.mimeData.dataRequested.connect(self.createData, QtCore.Qt.DirectConnection)

        drag = QtGui.QDrag(self)
        drag.setMimeData(self.mimeData)
        drag.setPixmap(QtGui.QPixmap(':/images/drag.png'))
        drag.exec_(QtCore.Qt.CopyAction)


if __name__ == '__main__':

    import sys

    app = QtGui.QApplication(sys.argv)
    window = SourceWidget()
    window.show()
    sys.exit(app.exec_())
